@@ -12,14 +12,14 @@ import (
 	"github.com/openshift/cluster-logging-operator/test/helpers"
 )
 
-var _ = Describe("CLO Managed LogForwarding", func() {
+var _ = Describe("[ClusterLogForwarder] Forwards logs", func() {
 	_, filename, _, _ := runtime.Caller(0)
 	logger.Infof("Running %s", filename)
 	var (
 		e2e = helpers.NewE2ETestFramework()
 	)
 
-	Describe("when ClusterLogging is configured with a collector, LogStore, and no explicit 'forwarding'", func() {
+	Describe("when the output is a CLO managed elasticsearch and no explicit forwarder is configured", func() {
 
 		BeforeEach(func() {
 			if err := e2e.DeployLogGenerator(); err != nil {
@@ -40,12 +40,12 @@ var _ = Describe("CLO Managed LogForwarding", func() {
 
 		AfterEach(func() {
 			e2e.Cleanup()
-			e2e.WaitForCleanupCompletion([]string{"fluentd", "elasticsearch"})
+			e2e.WaitForCleanupCompletion(helpers.OpenshiftLoggingNS, []string{"fluentd", "elasticsearch"})
 		}, helpers.DefaultCleanUpTimeout)
 
 		It("should default to forwarding logs to the spec'd logstore", func() {
-			Expect(e2e.LogStore.HasInfraStructureLogs(helpers.DefaultWaitForLogsTimeout)).To(BeTrue(), "Expected to find stored infrastructure logs")
-			Expect(e2e.LogStore.HasApplicationLogs(helpers.DefaultWaitForLogsTimeout)).To(BeTrue(), "Expected to find stored application logs")
+			Expect(e2e.LogStores["elasticsearch"].HasInfraStructureLogs(helpers.DefaultWaitForLogsTimeout)).To(BeTrue(), "Expected to find stored infrastructure logs")
+			Expect(e2e.LogStores["elasticsearch"].HasApplicationLogs(helpers.DefaultWaitForLogsTimeout)).To(BeTrue(), "Expected to find stored application logs")
 
 			//verify infra namespaces are not stored to their own index
 			elasticSearch := helpers.ElasticLogStore{Framework: e2e}
