@@ -1,10 +1,10 @@
 package helpers
 
 import (
+	"context"
 	"encoding/json"
 	"errors"
 	"fmt"
-	"path"
 	"strconv"
 	"strings"
 	"time"
@@ -89,7 +89,7 @@ type ElasticLogStore struct {
 	Framework *E2ETestFramework
 }
 
-func (es *ElasticLogStore) ApplicationLogs(timeToWait time.Duration) (string, error) {
+func (es *ElasticLogStore) ApplicationLogs(timeToWait time.Duration) (logs, error) {
 	panic("Method not implemented")
 }
 
@@ -97,7 +97,8 @@ func (es *ElasticLogStore) HasInfraStructureLogs(timeToWait time.Duration) (bool
 	err := wait.PollImmediate(defaultRetryInterval, timeToWait, func() (done bool, err error) {
 		indices, err := es.Indices()
 		if err != nil {
-			logger.Errorf("Error retrieving indices from elasticsearch %v", err)
+			//accept arbitrary errors like 'etcd leader change'
+			logger.Warnf("Error retrieving indices from elasticsearch %v", err)
 			return false, nil
 		}
 		return indices.HasInfraStructureLogs(), nil
@@ -109,7 +110,8 @@ func (es *ElasticLogStore) HasApplicationLogs(timeToWait time.Duration) (bool, e
 	err := wait.PollImmediate(defaultRetryInterval, timeToWait, func() (done bool, err error) {
 		indices, err := es.Indices()
 		if err != nil {
-			logger.Errorf("Error retrieving indices from elasticsearch %v", err)
+			//accept arbitrary errors like 'etcd leader change'
+			logger.Warnf("Error retrieving indices from elasticsearch %v", err)
 			return false, nil
 		}
 		return indices.HasApplicationLogs(), nil
@@ -121,7 +123,9 @@ func (es *ElasticLogStore) HasAuditLogs(timeToWait time.Duration) (bool, error)
 	err := wait.PollImmediate(defaultRetryInterval, timeToWait, func() (done bool, err error) {
 		indices, err := es.Indices()
 		if err != nil {
-			return false, err
+			//accept arbitrary errors like 'etcd leader change'
+			logger.Warnf("Error retrieving indices from elasticsearch %v", err)
+			return false, nil
 		}
 		return indices.HasAuditLogs(), nil
 	})
@@ -132,12 +136,21 @@ func (es *ElasticLogStore) GrepLogs(expr string, timeToWait time.Duration) (stri
 	return "Not Found", fmt.Errorf("Not implemented")
 }
 
+func (es *ElasticLogStore) RetrieveLogs() (map[string]string, error) {
+	return nil, fmt.Errorf("Not implemented")
+}
+
+func (es *ElasticLogStore) ClusterLocalEndpoint() string {
+	panic("Not implemented")
+}
+
 //Indices fetches the list of indices stored by Elasticsearch
 func (es *ElasticLogStore) Indices() (Indices, error) {
 	options := metav1.ListOptions{
 		LabelSelector: "component=elasticsearch",
 	}
-	pods, err := es.Framework.KubeClient.CoreV1().Pods(OpenshiftLoggingNS).List(options)
+
+	pods, err := es.Framework.KubeClient.CoreV1().Pods(OpenshiftLoggingNS).List(context.TODO(), options)
 	if err != nil {
 		return nil, err
 	}
@@ -160,26 +173,18 @@ func (es *ElasticLogStore) Indices() (Indices, error) {
 func (tc *E2ETestFramework) DeployAnElasticsearchCluster(pwd string) (cr *elasticsearch.Elasticsearch, pipelineSecret *corev1.Secret, err error) {
 	logger.Debug("DeployAnElasticsearchCluster")
 	logStoreName := "test-elastic-cluster"
-	workingDir := ""
-	if workingDir, pipelineSecret, err = tc.CreatePipelineSecret(pwd, logStoreName, "test-pipeline-to-elastic", map[string][]byte{}); err != nil {
+	if pipelineSecret, err = tc.CreatePipelineSecret(pwd, logStoreName, "test-pipeline-to-elastic", map[string][]byte{}); err != nil {
 		return nil, nil, err
 	}
 
+	opts := metav1.CreateOptions{}
 	esSecret := k8shandler.NewSecret(
 		logStoreName,
 		OpenshiftLoggingNS,
-		map[string][]byte{
-			"elasticsearch.key": utils.GetFileContents(path.Join(workingDir,"elasticsearch.key")),
-			"elasticsearch.crt": utils.GetFileContents(path.Join(workingDir,"elasticsearch.crt")),
-			"logging-es.key":    utils.GetFileContents(path.Join(workingDir,"logging-es.key")),
-			"logging-es.crt":    utils.GetFileContents(path.Join(workingDir,"logging-es.crt")),
-			"admin-key":         utils.GetFileContents(path.Join(workingDir,"system.admin.key")),
-			"admin-cert":        utils.GetFileContents(path.Join(workingDir,"system.admin.crt")),
-			"admin-ca":          utils.GetFileContents(path.Join(workingDir,"ca.crt")),
-		},
+		k8shandler.LoadElasticsearchSecretMap(),
 	)
 	logger.Debugf("Creating secret for an elasticsearch cluster: %s", esSecret.Name)
-	if esSecret, err = tc.KubeClient.Core().Secrets(OpenshiftLoggingNS).Create(esSecret); err != nil {
+	if esSecret, err = tc.KubeClient.CoreV1().Secrets(OpenshiftLoggingNS).Create(context.TODO(), esSecret, opts); err != nil {
 		return nil, nil, err
 	}
 	pvcSize := resource.MustParse("200G")
@@ -223,12 +228,13 @@ func (tc *E2ETestFramework) DeployAnElasticsearchCluster(pwd string) (cr *elasti
 		result := tc.KubeClient.RESTClient().Delete().
 			RequestURI(fmt.Sprintf("%s/%s", elasticsearchesLoggingURI, cr.Name)).
 			SetHeader("Content-Type", "application/json").
-			Do()
+			Do(context.TODO())
 		return result.Error()
 	})
 	tc.AddCleanup(func() error {
+		opts := metav1.DeleteOptions{}
 		for _, name := range []string{esSecret.Name, pipelineSecret.Name} {
-			if err := tc.KubeClient.Core().Secrets(OpenshiftLoggingNS).Delete(name, nil); err != nil {
+			if err := tc.KubeClient.CoreV1().Secrets(OpenshiftLoggingNS).Delete(context.TODO(), name, opts); err != nil {
 				return err
 			}
 		}
@@ -244,8 +250,10 @@ func (tc *E2ETestFramework) DeployAnElasticsearchCluster(pwd string) (cr *elasti
 		RequestURI(elasticsearchesLoggingURI).
 		SetHeader("Content-Type", "application/json").
 		Body(body).
-		Do()
-	tc.LogStore = &ElasticLogStore{
+		Do(context.TODO())
+
+	name := cr.GetName()
+	tc.LogStores[name] = &ElasticLogStore{
 		Framework: tc,
 	}
 	return cr, pipelineSecret, result.Error()
